import { echo } from "@atums/echo";
import { cookieService, sessionManager } from "#lib/auth";

import type { BaseResponse, ExtendedRequest, RouteDef } from "#types/server";

interface LogoutResponse extends BaseResponse {}

const routeDef: RouteDef = {
	method: ["POST", "DELETE"],
	accepts: "*/*",
	returns: "application/json",
};

async function handler(request: ExtendedRequest): Promise<Response> {
	try {
		const session = await sessionManager.getSession(request);

		if (!session) {
			const response: LogoutResponse = {
				code: 401,
				success: false,
				error: "Not authenticated",
			};
			return Response.json(response, { status: 401 });
		}

		await sessionManager.invalidateSession(request);
		const clearCookie = cookieService.clearCookie();

		const response: LogoutResponse = {
			code: 200,
			success: true,
			message: "Logged out successfully",
		};

		return Response.json(response, {
			status: 200,
			headers: {
				"Set-Cookie": clearCookie,
			},
		});
	} catch (error) {
		echo.error({
			message: "Error during user logout",
			error,
		});

		const response: LogoutResponse = {
			code: 500,
			success: false,
			error: "Internal server error",
		};
		return Response.json(response, { status: 500 });
	}
}

export { handler, routeDef };
